@@ -13,7 +13,7 @@
 #include <time.h>
 
 
-#define RFC3339_VERSION "0.0.12"
+#define RFC3339_VERSION "0.0.16"
 #define DAY_IN_SECS 86400
 #define HOUR_IN_SECS 3600
 #define MINUTE_IN_SECS 60
@@ -135,6 +135,7 @@ static void _parse_date(char *date_string, date_struct *d) {
     int status = sscanf(
         tokens, "%04d-%02d-%02d", &((*d).year), &((*d).month), &((*d).day)
     );
+    free((char*)tokens);
 
     // Validate parsed tokens
     if (status != 3) return;
@@ -256,7 +257,7 @@ static void _parse_time(char *time_string, time_struct *t) {
     // check for fractions
     if (*tokens == '.') {
         tokens++;
-        char fractions[6] = {0};
+        char fractions[7] = {0};
 
         // Substring fractions, max 6 digits for usec
         for (unsigned int i = 0; i < 6; i++) {
@@ -270,8 +271,8 @@ static void _parse_time(char *time_string, time_struct *t) {
         // convert fractions to uint
         status = sscanf(fractions, "%d", &((*t).fraction));
 
-        if (strlen(fractions) == 3) {
-            (*t).fraction = (*t).fraction * 1000; // convert msec to usec
+        if (strlen(fractions) < 6 && strlen(fractions) > 0) {
+            (*t).fraction = (*t).fraction * pow(10, 6 - strlen(fractions)); // convert msec to usec
         } else if (strlen(fractions) == 6) {
             // all fine, already in usec
         } else {
@@ -295,7 +296,14 @@ static void _parse_time(char *time_string, time_struct *t) {
     // parse timezone
     if ((*tokens == 'Z') || (*tokens == 'z')) {
         (*t).offset = 0;
-        (*t).ok = 1;
+
+        tokens++;
+        if (strlen(tokens) == 0) {
+            (*t).ok = 1;
+        } else {
+            (*t).ok = 0;
+        }
+
         goto cleanup;
     } else if ((*tokens == '+') || (*tokens == '-')) {
         unsigned int tz_hour, tz_minute;
@@ -316,7 +324,13 @@ static void _parse_time(char *time_string, time_struct *t) {
         }
 
         (*t).offset = tz_offset;
-        (*t).ok = 1;
+
+        tokens = tokens + 6;
+        if (strlen(tokens) == 0) {
+            (*t).ok = 1;
+        } else {
+            (*t).ok = 0;
+        }
     }
 
 cleanup:
@@ -548,10 +562,10 @@ static PyObject *FixedOffset_utcoffset(FixedOffset *self, PyObject *args) {
 
 /*
  * def dst(self, dt):
- *     return timedelta(seconds=self.offset * 60)
+ *     return timedelta(0)
  */
 static PyObject *FixedOffset_dst(FixedOffset *self, PyObject *args) {
-    return PyDelta_FromDSU(0, self->offset * 60, 0);
+    return PyDelta_FromDSU(0, 0, 0);
 }
 
 /*
@@ -973,7 +987,7 @@ static PyMethodDef rfc3339_methods[] = {
 #ifdef _PYTHON3
 static struct PyModuleDef Python3_module = {
     PyModuleDef_HEAD_INIT,
-    "rfc3339",
+    "udatetime.rfc3339",
     NULL,
     -1,
     rfc3339_methods,
@@ -1001,7 +1015,7 @@ initrfc3339(void)
 #ifdef _PYTHON3
     m = PyModule_Create(&Python3_module);
 #else
-    m = Py_InitModule("rfc3339", rfc3339_methods);
+    m = Py_InitModule("udatetime.rfc3339", rfc3339_methods);
 #endif
 
     if (m == NULL)
